Change log
==========

4.1 (2023-05-26)
----------------

- Change license to the Zope Public License (ZPL) version 2.1
  (`#15 <https://github.com/zopefoundation/roman/issues/15>`_)


4.0 (2023-02-28)
----------------

- Add support for Python 3.10, 3.11.

- Drop support for Python 2.7, 3.5, 3.6.


3.3 (2020-07-12)
----------------

- added support for Python 3.9

- added CLI command ``roman`` with ``-r/--reverse`` to convert back from Roman

- added simple usage instructions


3.2 (2019-04-14)
----------------

- expanded test coverage

- Added support for 0 -> N
  (see https://en.wikipedia.org/wiki/Roman_numerals#Zero)

- Added support for Python 3.8


3.1 (2018-10-24)
----------------

- Added support for Python 3.7.


3.0 (2018-05-28)
----------------

- Added support for Python 3.5, 3.6 and PyPy3.

- Dropped support for Python 2.6 and 3.3.


2.0.0 (2013-02-25)
------------------

- Added Python 3.3 and PyPy support.

- Added tests.


1.4.0 (2009-07-23)
------------------

- Initial PyPI release.
